;; Index file to load all of the releavant reports.

(gnc:support "report/report-list.scm")
(gnc:depend "report/average-balance.scm")
(gnc:depend "report/balance-and-pnl.scm")
(gnc:depend "report/folio.scm")
(gnc:depend "report/hello-world.scm")
(gnc:depend "report/transaction-report.scm")
(gnc:depend "report/taxtxf.scm")
;(gnc:depend "report/budget-report.scm")
